==> haskell-vty-unix-0.2.0.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-unix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-unix
version:              0.2.0.0
visibility:           public
id:                   vty-unix-0.2.0.0-ETdI9HiL15IHFbG4JNROG1
key:                  vty-unix-0.2.0.0-ETdI9HiL15IHFbG4JNROG1
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Unix backend for Vty
description:          This package provides Unix terminal support for Vty.
category:             User Interfaces
abi:                  ec16c9d51c1e17d502c2ad935fd51caf
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Vty.Platform.Unix
    Graphics.Vty.Platform.Unix.Input
    Graphics.Vty.Platform.Unix.Input.Classify
    Graphics.Vty.Platform.Unix.Input.Classify.Parse
    Graphics.Vty.Platform.Unix.Input.Classify.Types
    Graphics.Vty.Platform.Unix.Input.Focus
    Graphics.Vty.Platform.Unix.Input.Loop
    Graphics.Vty.Platform.Unix.Input.Mouse
    Graphics.Vty.Platform.Unix.Input.Paste
    Graphics.Vty.Platform.Unix.Input.Terminfo
    Graphics.Vty.Platform.Unix.Input.Terminfo.ANSIVT
    Graphics.Vty.Platform.Unix.Output
    Graphics.Vty.Platform.Unix.Output.Color
    Graphics.Vty.Platform.Unix.Output.TerminfoBased
    Graphics.Vty.Platform.Unix.Output.XTermColor
    Graphics.Vty.Platform.Unix.Settings

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-unix
hs-libraries:         HSvty-unix-0.2.0.0-ETdI9HiL15IHFbG4JNROG1
includes:             cbits/gwinsz.h
depends:
    base-4.17.2.1 blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-mtl-0.2.0.3-vQELA1onhlLfPXHvjZtx7
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3 mtl-2.2.2
    parsec-3.1.16.1 stm-2.5.1.0 terminfo-0.4.1.5 transformers-0.5.6.2
    unix-2.7.3 utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO
    vector-0.13.1.0-4yrO9MMzvlSAj3sbKvUmkp
    vty-6.1-5FnHvES25i5IywyEwlsfOA

haddock-interfaces:   /usr/share/doc/haskell-vty-unix/html/vty-unix.haddock
haddock-html:         /usr/share/doc/haskell-vty-unix/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-unix-0.2.0.0-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vty-unix.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty-unix
version:              0.2.0.0
visibility:           public
id:                   vty-unix-0.2.0.0-JXhys9BgbLqJpHPTU31ei2
key:                  vty-unix-0.2.0.0-JXhys9BgbLqJpHPTU31ei2
license:              BSD-3-Clause
copyright:            (c) 2023 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
synopsis:             Unix backend for Vty
description:          This package provides Unix terminal support for Vty.
category:             User Interfaces
abi:                  a4541e9f66524430eda9857791df9a2a
exposed:              True
exposed-modules:
    Data.Terminfo.Eval Data.Terminfo.Parse Graphics.Vty.Platform.Unix
    Graphics.Vty.Platform.Unix.Input
    Graphics.Vty.Platform.Unix.Input.Classify
    Graphics.Vty.Platform.Unix.Input.Classify.Parse
    Graphics.Vty.Platform.Unix.Input.Classify.Types
    Graphics.Vty.Platform.Unix.Input.Focus
    Graphics.Vty.Platform.Unix.Input.Loop
    Graphics.Vty.Platform.Unix.Input.Mouse
    Graphics.Vty.Platform.Unix.Input.Paste
    Graphics.Vty.Platform.Unix.Input.Terminfo
    Graphics.Vty.Platform.Unix.Input.Terminfo.ANSIVT
    Graphics.Vty.Platform.Unix.Output
    Graphics.Vty.Platform.Unix.Output.Color
    Graphics.Vty.Platform.Unix.Output.TerminfoBased
    Graphics.Vty.Platform.Unix.Output.XTermColor
    Graphics.Vty.Platform.Unix.Settings

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-unix-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty-unix
hs-libraries:         HSvty-unix-0.2.0.0-JXhys9BgbLqJpHPTU31ei2
includes:             cbits/gwinsz.h
depends:
    base-4.17.2.1 blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-mtl-0.2.0.3-vQELA1onhlLfPXHvjZtx7
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3 mtl-2.2.2
    parsec-3.1.16.1 stm-2.5.1.0 terminfo-0.4.1.5 transformers-0.5.6.2
    unix-2.7.3 utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-EmsVweixOBx5SizhJaK3bm
    vty-6.1-CWgCtA0fP5b6tAqdGxpi0I

haddock-interfaces:   /usr/share/doc/haskell-vty-unix/html/vty-unix.haddock
haddock-html:         /usr/share/doc/haskell-vty-unix/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
